from setuptools import setup

setup(
    name='bowler',
    description='a hat',
    version='0.0.1',
    author='John Reese',
    author_email='john@noswap.com',
    url='https://github.com/jreese',
    classifiers=[
        'Development Status :: 1 - Planning',
        'Intended Audience :: Developers',
    ],
    license='MIT',
    packages=[],
    setup_requires=['setuptools>=38.6.0'],
    install_requires=[
    ],
)
